==> 0.4.1&file=in_ffsox-2a-0.4.1-src.tar.gz: in_ffsox-2a-0.4.1/in_ffsox/slider.h <==
/*
 * slider.h
 * Copyright (C) 2010 - 2013 Peter Belkner <pbelkner@snafu.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#if defined (PREFS_SYNC_SLIDER) // [
#define SLIDER(group,name,format,q,type,ID) \
static void priv_sync_##group##_##name(priv_t *p, HWND hDlg) \
{ \
  prefgui_t *rg=p->group.name; \
  char buf[128]; \
 \
  if (NULL!=rg) { \
    sprintf(buf,format,q*rg->vmt->get_##type(rg,hDlg)); \
    SetDlgItemTextA(hDlg,IDC_STATIC_##ID,buf); \
  } \
}
#elif defined (PREFS_INIT_SLIDER) // ] [
#define SLIDER(group,name,format,q,type,ID) \
      case IDC_SLIDER_##ID: \
        p->group.name=pg; \
        priv_sync_##group##_##name(p,hDlg); \
        break;
#elif defined (PREFS_NOTIFY_SLIDER) // ] [
#define SLIDER(group,name,format,q,type,ID) \
    case IDC_SLIDER_##ID: \
      priv_sync_##group##_##name(p,hDlg); \
      break;
#endif // ]

#if defined (PREFS_GENERAL) || defined (PREFS_CONV_GENERAL) // [
SLIDER(rg,weight,"%.0f%%",100.0,double,RG_WEIGHT)
#elif defined (PREFS_AUDIO) || defined (PREFS_CONV_AUDIO) // ] [
SLIDER(audio,queue_size,"%d Pkts",1,int,AUDIO_QUEUE_SIZE)
SLIDER(audio,preamp,"%.1f dB",1.0,double,AUDIO_PREAMP)
#if defined (PREFS_AUDIO_DRC) // [
// https://ffmpeg.org/ffmpeg-codecs.html#AC_002d3-Decoder-Options
// -drc_scale value
//     Dynamic Range Scale Factor. The factor to apply to dynamic range
//     values from the AC-3 stream. This factor is applied exponentially.
//     There are 3 notable scale factor ranges:
//     drc_scale == 0
//         DRC disabled. Produces full range audio. 
//     0 < drc_scale <= 1
//         DRC enabled. Applies a fraction of the stream DRC value. Audio
//         reproduction is between full range and full compression. 
//     drc_scale > 1
//         DRC enabled. Applies drc_scale asymmetrically. Loud sounds are
//         fully compressed. Soft sounds are enhanced. 
SLIDER(audio,drc_scale,"%.1f",AUDIO_DRC_Q,double,AUDIO_AC3_DRC_SCALE)
#endif // ]
#elif defined (PREFS_VIDEO) // ] [
SLIDER(video,queue_size,"%d Pkts",1,int,VIDEO_QUEUE_SIZE)
SLIDER(video,min_drift,"%.02f s",0.001,double,VIDEO_MIN_DRIFT)
SLIDER(video,max_drift,"%.02f s",0.001,double,VIDEO_MAX_DRIFT)
#elif defined (PREFS_TRANS) // ] [
#endif // ]

#if defined (SLIDER) // {
#undef SLIDER
#endif // }

#if defined (PREFS_NOTIFY_SLIDER) // {
#undef PREFS_NOTIFY_SLIDER
#elif defined (PREFS_INIT_SLIDER) // } {
#undef PREFS_INIT_SLIDER
#elif defined (PREFS_SYNC_SLIDER) // } {
#undef PREFS_SYNC_SLIDER
#endif // }

==> 0.4.2&file=in_ffsox-2a-0.4.2-src.tar.gz: in_ffsox-2a-0.4.2/in_ffsox/slider.h <==
/*
 * slider.h
 * Copyright (C) 2010 - 2013 Peter Belkner <pbelkner@snafu.de>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#if defined (PREFS_SYNC_SLIDER) // [
#define SLIDER(group,name,format,q,type,ID) \
static void priv_sync_##group##_##name(priv_t *p, HWND hDlg) \
{ \
  prefgui_t *rg=p->group.name; \
  char buf[128]; \
 \
  if (NULL!=rg) { \
    sprintf(buf,format,q*rg->vmt->get_##type(rg,hDlg)); \
    SetDlgItemTextA(hDlg,IDC_STATIC_##ID,buf); \
  } \
}
#elif defined (PREFS_INIT_SLIDER) // ] [
#define SLIDER(group,name,format,q,type,ID) \
      case IDC_SLIDER_##ID: \
        p->group.name=pg; \
        priv_sync_##group##_##name(p,hDlg); \
        break;
#elif defined (PREFS_NOTIFY_SLIDER) // ] [
#define SLIDER(group,name,format,q,type,ID) \
    case IDC_SLIDER_##ID: \
      priv_sync_##group##_##name(p,hDlg); \
      break;
#endif // ]

#if defined (PREFS_GENERAL) || defined (PREFS_CONV_GENERAL) // [
SLIDER(rg,weight,"%.0f%%",RG_WEIGHT_Q,double,RG_WEIGHT)
#if defined (VIS_DELAY) // [
SLIDER(delay,ms,"%.0f ms",VIS_DELAY_MS_Q,double,WINAMP_VIS_DELAY_MS)
#endif // ]
#elif defined (PREFS_AUDIO) || defined (PREFS_CONV_AUDIO) // ] [
SLIDER(audio,queue_size,"%d Pkts",1,int,AUDIO_QUEUE_SIZE)
SLIDER(audio,preamp,"%.1f dB",1.0,double,AUDIO_PREAMP)
#if defined (PREFS_AUDIO_DRC) // [
// https://ffmpeg.org/ffmpeg-codecs.html#AC_002d3-Decoder-Options
// -drc_scale value
//     Dynamic Range Scale Factor. The factor to apply to dynamic range
//     values from the AC-3 stream. This factor is applied exponentially.
//     There are 3 notable scale factor ranges:
//     drc_scale == 0
//         DRC disabled. Produces full range audio. 
//     0 < drc_scale <= 1
//         DRC enabled. Applies a fraction of the stream DRC value. Audio
//         reproduction is between full range and full compression. 
//     drc_scale > 1
//         DRC enabled. Applies drc_scale asymmetrically. Loud sounds are
//         fully compressed. Soft sounds are enhanced. 
SLIDER(audio,drc_scale,"%.1f",AUDIO_DRC_Q,double,AUDIO_AC3_DRC_SCALE)
#endif // ]
#elif defined (PREFS_VIDEO) // ] [
SLIDER(video,queue_size,"%d Pkts",1,int,VIDEO_QUEUE_SIZE)
SLIDER(video,min_drift,"%.02f s",0.001,double,VIDEO_MIN_DRIFT)
SLIDER(video,max_drift,"%.02f s",0.001,double,VIDEO_MAX_DRIFT)
#elif defined (PREFS_TRANS) // ] [
#endif // ]

#if defined (SLIDER) // {
#undef SLIDER
#endif // }

#if defined (PREFS_NOTIFY_SLIDER) // {
#undef PREFS_NOTIFY_SLIDER
#elif defined (PREFS_INIT_SLIDER) // } {
#undef PREFS_INIT_SLIDER
#elif defined (PREFS_SYNC_SLIDER) // } {
#undef PREFS_SYNC_SLIDER
#endif // }
